@@ -4,7 +4,7 @@ use warnings;
 
 package Dist::Zilla::App::Command::dumpwith;
 
-our $VERSION = '0.002003';
+our $VERSION = '0.002010';
 
 # ABSTRACT: Dump all plugins that 'do' a certain role
 
@@ -23,6 +23,7 @@ our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
 
 
 use Dist::Zilla::App '-command';
+use Try::Tiny qw( try catch );
 
 ## no critic ( ProhibitAmbiguousNames)
 sub abstract { return 'Dump all plugins that "do" a specific role' }
@@ -64,7 +65,7 @@ sub _has_dz_role {
 }
 
 sub validate_args {
-  my ( $self, undef, $args ) = @_;
+  my ( $self, $opt, $args ) = @_;
   for my $arg ( @{$args} ) {
     if ( $arg =~ /\A-(.*)\z/msx ) {
       $self->_has_dz_role($1);
@@ -73,32 +74,71 @@ sub validate_args {
       $self->_has_module($arg);
     }
   }
+  my $theme = $opt->color_theme || 'basic::blue';
+  try {
+    $self->_load_color_theme($theme);
+  }
+  catch {
+    my $error = shift;
+    require Carp;
+    my $message = $error . qq[\n\n];
+    $message .= sprintf "^ Was seen attempting to load theme <%s>\n", $theme;
+    $message .= sprintf 'available themes are: %s', ( join q{, }, $self->_available_themes );
+    Carp::croak($message);
+  };
   return 1;
 }
 
-sub _get_color_theme {
-  my ( undef, $opt, $default ) = @_;
-  return $default unless $opt->color_theme;
-  return $opt->color_theme;
+sub _available_themes {
+  my (undef) = @_;
+  require Path::ScanINC;
+  my (@theme_dirs) = Path::ScanINC->new()->all_dirs( 'Dist', 'Zilla', 'dumpphases', 'Theme' );
+  if ( not @theme_dirs ) {
+    require Carp;
+    ## no critic (ValuesAndExpressions::RequireInterpolationOfMetachars)
+    Carp::cluck('Found no theme dirs in @INC matching Dist/Zilla/dumpphases/Theme/');
+  }
+  my (%themes);
+  require Path::Tiny;
+  for my $dir (@theme_dirs) {
+    my $it = Path::Tiny->new($dir)->iterator(
+      {
+        recurse         => 1,
+        follow_symlinks => 0,
+      },
+    );
+    while ( my $item = $it->() ) {
+      next unless $item =~ /[.]pm\z/msx;
+      next if -d $item;
+      my $theme_name = $item->relative($dir);
+      $theme_name =~ s{[.]pm\z}{}msx;
+      $theme_name =~ s{/}{::}msxg;
+      $themes{$theme_name} = 1;
+    }
+  }
+  ## no critic (Variables::ProhibitUnusedVarsStricter)
+  return ( my (@list) = sort keys %themes );
 }
 
-sub _get_theme_instance {
-  my ( undef, $theme ) = @_;
+sub _load_color_theme {
+  my ( undef, $color_theme ) = @_;
   require Module::Runtime;
-  my $theme_module = Module::Runtime::compose_module_name( 'Dist::Zilla::dumpphases::Theme', $theme );
+  my $theme_module = Module::Runtime::compose_module_name( 'Dist::Zilla::dumpphases::Theme', $color_theme );
   Module::Runtime::require_module($theme_module);
-  return $theme_module->new();
+  return $theme_module;
 }
 
 sub execute {
   my ( $self, $opt, $args ) = @_;
-  my $zilla = $self->zilla;
 
-  my $theme = $self->_get_theme_instance( $self->_get_color_theme( $opt, 'basic::blue' ) );
+  my $theme_module = $self->_load_color_theme( $opt->color_theme || 'basic::blue' );
+  my $theme = $theme_module->new();
 
   require Scalar::Util;
+  my $zilla;
   for my $arg ( @{$args} ) {
     $theme->print_section_prelude( 'role: ', $arg );
+    $zilla ||= $self->zilla;
     for my $plugin ( @{ $zilla->plugins_with($arg) } ) {
       $theme->print_star_assoc( $plugin->plugin_name, Scalar::Util::blessed($plugin) );
     }
@@ -121,7 +161,7 @@ Dist::Zilla::App::Command::dumpwith - Dump all plugins that 'do' a certain role
 
 =head1 VERSION
 
-version 0.002003
+version 0.002010
 
 =head1 SYNOPSIS
 
@@ -176,7 +216,7 @@ Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Kent Fredric <kentfredric@gmail.com>.
+This software is copyright (c) 2015 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
